Evaluation of the Vorob'ev criterion for candidate points x, assuming that some other points are also going to be evaluated. To be used in optimization routines, like in max_vorob_parallel_gpc. To avoid numerical instabilities, the new points are evaluated only if they are not too close to an existing observation, or if there is some observation noise. The criterion is the integral of the posterior Vorob'ev uncertainty.
vorob_optim_parallel2_gpc(
x,
other.points,
integration.points,
integration.weights = NULL,
intpoints.oldmean,
intpoints.oldsd,
precalc.data,
object,
new.noise.var = NULL,
batchsize,
alpha,
current.vorob,
seed = NULL
)Parallel Vorob'ev value
input vector of size d at which one wants to evaluate the criterion.
vector giving the other batchsize-1 points at which one wants to evaluate the criterion.
p*d matrix of points for numerical integration in the design space.
vector of size p corresponding to the weights of these integration points.
vector of size p corresponding to the latent GP mean at the integration points before adding x to the design of experiments.
vector of size p corresponding to the latent GP standard deviation at the integration points before adding x to the design of experiments.
list containing precalculated data. This list can be generated using the precomputeUpdateData function.
object of class gpcm.
optional scalar value of the noise variance of the new observations.
number of points to sample simultaneously. The sampling criterion will return batchsize points at a time for sampling.
a scalar representing the Vorob'ev threshold.
current value of the vorob criterion (before adding new observations).
to fix the seed.
Morgane MENZ, Delphine SINOQUET, Miguel MUNOZ-ZUNIGA. Contributors: Naoual SERRAJI.
Menz, M., Munoz-Zuniga, M., Sinoquet, D. Estimation of simulation failure set with active learning based on Gaussian Process classifiers and random set theory (2023). https://hal.science/hal-03848238.
Chevalier, C. Fast uncertainty reduction strategies relying on Gaussian process models PhD Thesis. University of Bern (2013).
Bachoc, F., Helbert, C. & Picheny, V. Gaussian process optimization with failures: classification and convergence proof. J Glob Optim 78, 483–506 (2020). tools:::Rd_expr_doi("10.1007/s10898-020-00920-0").
max_vorob_parallel_gpc()